@@ -1,4 +1,4 @@
 ;;;###autoload
 (package-provide 'ruby-modes
-		 :version 1.00
-		 :type 'single-file)
+		 :version 1.01
+		 :type 'regular)
